pub enum SqlDataMode {
InsertStatements,
CopyStatements,
}Expand description
How to generate statements for inserting data.
Variants
InsertStatements
Generate insert statements. A bit slower on import, but might work across many database systems. Example:
insert into public.store (store_id, manager_staff_id, address_id, last_update) values
(1, 1, 1, E'2006-02-15 09:57:12'),
(2, 2, 2, E'2006-02-15 09:57:12');CopyStatements
Generate copy statements. Much faster on import, but might not work across many database systems. Example:
copy public.store (store_id, manager_staff_id, address_id, last_update) from stdin with (format text, header false);
1 1 1 2006-02-15 09:57:12
2 2 2 2006-02-15 09:57:12
\.Trait Implementations
Sourceimpl Clone for SqlDataMode
impl Clone for SqlDataMode
Sourcefn clone(&self) -> SqlDataMode
fn clone(&self) -> SqlDataMode
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SqlDataMode
impl Debug for SqlDataMode
Sourceimpl Display for SqlDataMode
impl Display for SqlDataMode
Sourceimpl From<String> for SqlDataMode
impl From<String> for SqlDataMode
Sourceimpl PartialEq for SqlDataMode
impl PartialEq for SqlDataMode
impl Eq for SqlDataMode
impl StructuralPartialEq for SqlDataMode