pub struct IdentifierQuoter { /* private fields */ }Expand description
Provides utilities for quoting identifiers in PostgreSQL as needed.
Implementations
Sourceimpl IdentifierQuoter
impl IdentifierQuoter
Sourcepub fn new(keywords: HashMap<String, AllowedKeywordUsage>) -> Self
pub fn new(keywords: HashMap<String, AllowedKeywordUsage>) -> Self
Creates a new IdentifierQuoter with the specified keywords and their allowed usages.
Sourcepub fn empty() -> Self
pub fn empty() -> Self
Creates a new IdentifierQuoter with no keywords.
This is mainly useful for testing as it doesn’t require connecting to Postgres.
Sourcepub fn quote(
&self,
identifier: impl AsRef<str>,
usage: AttemptedKeywordUsage,
) -> String
pub fn quote( &self, identifier: impl AsRef<str>, usage: AttemptedKeywordUsage, ) -> String
Quotes an identifier as needed.
Sourcepub fn quote_iter<'a, 's, S: AsRef<str>, I: IntoIterator<Item = S>>(
&'a self,
identifiers: I,
usage: AttemptedKeywordUsage,
) -> impl Iterator<Item = String> + 'awhere
<I as IntoIterator>::IntoIter: 'a,
pub fn quote_iter<'a, 's, S: AsRef<str>, I: IntoIterator<Item = S>>(
&'a self,
identifiers: I,
usage: AttemptedKeywordUsage,
) -> impl Iterator<Item = String> + 'awhere
<I as IntoIterator>::IntoIter: 'a,
Quotes multiple identifiers as needed.