pub struct ParallelCopyDestinationNotAvailable { /* private fields */ }Expand description
A CopyDestination that panics when used. Cannot be constructed outside this module, but is available for type reference to indicate Parallel copy is not supported.