PostgresClientWrapper

Struct PostgresClientWrapper 

pub struct PostgresClientWrapper { /* private fields */ }
A wrapper around the elefant-client connection pool, providing a convenient interface.

Implementations

Source

impl PostgresClientWrapper

pub async fn new(settings: PostgresConnectionSettings) -> Result<Self>

Create a new PostgresClientWrapper.

This will connect to the postgres server to figure out the version of the server. If the version is less than 12, an error is returned.

pub fn version(&self) -> i32

Get the version of the postgres server

pub fn pool(&self) -> &TokioPostgresPool

Get a reference to the underlying pool

pub async fn execute_non_query(&self, sql: &str) -> Result

Execute a query that does not return any results.

pub async fn get_results<T: FromSqlRowOwned>(&self, sql: &str) -> Result<Vec<T>>

Execute a query that returns results.

pub async fn get_result<T: FromSqlRowOwned>(&self, sql: &str) -> Result<T>

Execute a query that returns a single result.

pub async fn get_single_results<T: FromSqlOwned>( &self, sql: &str, ) -> Result<Vec<T>>

Execute a query that returns a single column of results.

pub async fn get_single_result<T: FromSqlOwned>(&self, sql: &str) -> Result<T>

Execute a query that returns a single column of a single row of results.