pub struct TableData<R: TableDataReader, C: AsyncCleanup> {
pub data: R,
pub data_format: DataFormat,
pub cleanup: C,
}Expand description
Data in a table. This data can be read from the data source using the reader.
Make sure to call cleanup when you have read all the data from the reader.
Fields
data: Rdata_format: DataFormatcleanup: CTrait Implementations
Sourceimpl<R: TableDataReader, C: AsyncCleanup> AsyncCleanup for TableData<R, C>
impl<R: TableDataReader, C: AsyncCleanup> AsyncCleanup for TableData<R, C>