pub struct PostgresClientWrapper { /* private fields */ }Expand description
A wrapper around the elefant-client connection pool, providing a convenient interface.
Implementations
Sourceimpl PostgresClientWrapper
impl PostgresClientWrapper
Sourcepub async fn new(settings: PostgresConnectionSettings) -> Result<Self>
pub async fn new(settings: PostgresConnectionSettings) -> Result<Self>
Create a new PostgresClientWrapper.
This will connect to the postgres server to figure out the version of the server. If the version is less than 12, an error is returned.
Sourcepub fn pool(&self) -> &TokioPostgresPool
pub fn pool(&self) -> &TokioPostgresPool
Get a reference to the underlying pool
Sourcepub async fn execute_non_query(&self, sql: &str) -> Result
pub async fn execute_non_query(&self, sql: &str) -> Result
Execute a query that does not return any results.
Sourcepub async fn get_results<T: FromSqlRowOwned>(&self, sql: &str) -> Result<Vec<T>>
pub async fn get_results<T: FromSqlRowOwned>(&self, sql: &str) -> Result<Vec<T>>
Execute a query that returns results.
Sourcepub async fn get_result<T: FromSqlRowOwned>(&self, sql: &str) -> Result<T>
pub async fn get_result<T: FromSqlRowOwned>(&self, sql: &str) -> Result<T>
Execute a query that returns a single result.
Sourcepub async fn get_single_results<T: FromSqlOwned>(
&self,
sql: &str,
) -> Result<Vec<T>>
pub async fn get_single_results<T: FromSqlOwned>( &self, sql: &str, ) -> Result<Vec<T>>
Execute a query that returns a single column of results.
Sourcepub async fn get_single_result<T: FromSqlOwned>(&self, sql: &str) -> Result<T>
pub async fn get_single_result<T: FromSqlOwned>(&self, sql: &str) -> Result<T>
Execute a query that returns a single column of a single row of results.